@@ -1,13 +1,26 @@
 """A&AI project module."""
+#   Copyright 2022 Orange, Deutsche Telekom AG
+#
+#   Licensed under the Apache License, Version 2.0 (the "License");
+#   you may not use this file except in compliance with the License.
+#   You may obtain a copy of the License at
+#
+#       http://www.apache.org/licenses/LICENSE-2.0
+#
+#   Unless required by applicable law or agreed to in writing, software
+#   distributed under the License is distributed on an "AS IS" BASIS,
+#   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+#   See the License for the specific language governing permissions and
+#   limitations under the License.
 
 from typing import Any, Dict, Iterator
 
 from onapsdk.utils.jinja import jinja_env
 
-from ..aai_element import AaiElement
+from ..aai_element import AaiResource
 
 
-class Project(AaiElement):
+class Project(AaiResource):
     """Project class."""
 
     def __init__(self, name: str, resource_version: str) -> None:
@@ -29,7 +42,7 @@ class Project(AaiElement):
             Project: Project object
 
         """
-        url: str = f"{cls.base_url}{cls.api_version}/business/projects"
+        url: str = cls.get_all_url()
         for project in cls.send_message_json("GET",
                                              "Get A&AI projects",
                                              url).get("project", []):
@@ -38,6 +51,16 @@ class Project(AaiElement):
                 project.get("resource-version")
             )
 
+    @classmethod
+    def get_all_url(cls) -> str:  # pylint: disable=arguments-differ
+        """Return url to get all projects.
+
+        Returns:
+            str: Url to get all projects
+
+        """
+        return f"{cls.base_url}{cls.api_version}/business/projects"
+
     def __repr__(self) -> str:
         """Project object representation.
 
